@@ -60,18 +60,16 @@ int bchswSampler(register WORD In[], register WORD Out[], register LPVOID Cargo)
     double power;
     gboolean shift;
 
-    LPBCHSWADJUSTS bchsw = (LPBCHSWADJUSTS) Cargo;
-    
+    LPBCHSWADJUSTS bchsw = (LPBCHSWADJUSTS) Cargo;    
+
     cmsLabEncoded2Float(&LabIn, In);
-     
-    cmsLab2LCh(&LChIn, &LabIn);
+         // Move white point in Lab
 
-    // Do some adjusts on LCh
-    
-    LChOut.L = LChIn.L * bchsw ->Exposure + bchsw ->Brightness;
+    cmsLab2XYZ(&bchsw ->WPsrc,  &XYZ, &LabIn);
+    cmsXYZ2Lab(&bchsw ->WPdest, &LabIn, &XYZ);
 
-    shift = (LChOut.L > 0.5);
-    l = (LChOut.L + 100) / 200;
+    shift = (LabIn.L > 0.5);
+    l = LabIn.L / 100;
     if (shift)
 	    l = 1.0 - l;
 
@@ -88,19 +86,19 @@ int bchswSampler(register WORD In[], register WORD Out[], register LPVOID Cargo)
     if (shift)
 	    l = 1.0 - l;
 
-    LChOut.L = l * 200 - 100;
+    LabIn.L = l * 100;
 
+    cmsLab2LCh(&LChIn, &LabIn);
+
+    // Do some adjusts on LCh
+    
+    LChOut.L = LChIn.L * bchsw ->Exposure + bchsw ->Brightness;
 
     LChOut.C = MAX (0, LChIn.C + bchsw ->Saturation);
     LChOut.h = LChIn.h + bchsw ->Hue;
     
     cmsLCh2Lab(&LabOut, &LChOut);
 
-    // Move white point in Lab
-
-    cmsLab2XYZ(&bchsw ->WPsrc,  &XYZ, &LabOut);
-    cmsXYZ2Lab(&bchsw ->WPdest, &LabOut, &XYZ);
-
     // Back to encoded
 
     cmsFloat2LabEncoded(Out, &LabOut);
@@ -119,61 +117,58 @@ cmsHPROFILE LCMSEXPORT f_cmsCreateBCHSWabstractProfile(int nLUTPoints,
 						       double Contrast,
 						       double Hue,
 						       double Saturation,
-						       cmsCIExyY current_wp,
-						       cmsCIExyY destination_wp,
+						       LPcmsCIExyY current_wp,
+						       LPcmsCIExyY destination_wp,
 						       LPGAMMATABLE Tables [])
 {
-     cmsHPROFILE hICC;
-     LPLUT Lut;
-     BCHSWADJUSTS bchsw;
-     cmsCIExyY WhitePnt;
-
-     bchsw.Exposure   = Exposure;
-     bchsw.Brightness = Bright;
-     bchsw.Contrast   = Contrast;
-     bchsw.Hue        = Hue;
-     bchsw.Saturation = Saturation;
-     
-     cmsxyY2XYZ(&bchsw.WPsrc, &current_wp);
-     cmsxyY2XYZ(&bchsw.WPdest, &destination_wp);
-    
-      hICC = _cmsCreateProfilePlaceholder();
-       if (!hICC)                          // can't allocate
-            return NULL;
-              
-
-       cmsSetDeviceClass(hICC,      icSigAbstractClass);
-       cmsSetColorSpace(hICC,       icSigLabData);
-       cmsSetPCS(hICC,              icSigLabData);
-
-       cmsSetRenderingIntent(hICC,  INTENT_PERCEPTUAL); 
-
-      
-       // Creates a LUT with 3D grid only
-       Lut = cmsAllocLUT();
-
-
-       cmsAlloc3DGrid(Lut, nLUTPoints, 3, 3);
-
-       if (Tables != NULL)
+	cmsHPROFILE hICC;
+	LPLUT Lut;
+	BCHSWADJUSTS bchsw;
+	cmsCIExyY WhitePnt;
+	
+	bchsw.Exposure   = Exposure;
+	bchsw.Brightness = Bright;
+	bchsw.Contrast   = Contrast;
+	bchsw.Hue        = Hue;
+	bchsw.Saturation = Saturation;
+	
+	cmsxyY2XYZ(&bchsw.WPsrc, current_wp);
+	cmsxyY2XYZ(&bchsw.WPdest, destination_wp);
+	
+	hICC = _cmsCreateProfilePlaceholder();
+	if (!hICC)                          // can't allocate
+		return NULL;
+	
+	cmsSetDeviceClass(hICC,      icSigAbstractClass);
+	cmsSetColorSpace(hICC,       icSigLabData);
+	cmsSetPCS(hICC,              icSigLabData);
+	
+	cmsSetRenderingIntent(hICC,  INTENT_PERCEPTUAL); 
+	
+	// Creates a LUT with 3D grid only
+	Lut = cmsAllocLUT();
+	
+	cmsAlloc3DGrid(Lut, nLUTPoints, 3, 3);
+	
+	if (Tables != NULL)
 	       cmsAllocLinearTable (Lut, Tables, 1);
-
+	
        if (!cmsSample3DGrid(Lut, bchswSampler, (LPVOID) &bchsw, 0)) {
-
-                // Shouldn't reach here
-                cmsFreeLUT(Lut);
-                cmsCloseProfile(hICC);
-                return NULL;
+	       
+	       // Shouldn't reach here
+	       cmsFreeLUT(Lut);
+	       cmsCloseProfile(hICC);
+	       return NULL;
        }    
        
        // Create tags
-        
-       cmsAddTag(hICC, icSigDeviceMfgDescTag,      (LPVOID) "(lcms internal)"); 
-       cmsAddTag(hICC, icSigProfileDescriptionTag, (LPVOID) "lcms BCHSW abstract profile");  
+       
+       cmsAddTag(hICC, icSigDeviceMfgDescTag,      (LPVOID) "(f-spot internal)"); 
+       cmsAddTag(hICC, icSigProfileDescriptionTag, (LPVOID) "f-spot BCHSW abstract profile");  
        cmsAddTag(hICC, icSigDeviceModelDescTag,    (LPVOID) "BCHSW built-in");      
        
        cmsAddTag(hICC, icSigMediaWhitePointTag, (LPVOID) cmsD50_XYZ());
-
+       
        cmsAddTag(hICC, icSigAToB0Tag, (LPVOID) Lut);
        
        // LUT is already on virtual profile
@@ -182,3 +177,33 @@ cmsHPROFILE LCMSEXPORT f_cmsCreateBCHSWabstractProfile(int nLUTPoints,
        // Ok, done
        return hICC;
 }
+
+LPGAMMATABLE
+f_cms_gamma_table_new (unsigned short data[], int start, int length)
+{
+	LPGAMMATABLE table = cmsAllocGamma (length);
+	int i;
+	if (!table)
+		return NULL;
+
+	data += start;
+
+	for (i = 0; i < length; i++)
+		table->GammaTable [i] = data [i];
+
+	g_warning ("table %p, count = %d v[0] = %d", table, table->nEntries, table->GammaTable [0]);
+	
+	return table;
+}
+
+ushort *
+f_cms_gamma_table_get_values (LPGAMMATABLE table)
+{
+	return &(table->GammaTable [0]);
+}
+
+int
+f_cms_gamma_table_get_count (LPGAMMATABLE table)
+{
+	return table->nEntries;
+}
