@@ -14,6 +14,8 @@ using System;
 using Cairo;
 using Mono.Unix;
 
+using FSpot.UI.Dialog;
+using FSpot.Utils;
 namespace FSpot.Editors {
 	public class SoftFocus : EffectEditor {
 		Widgets.SoftFocus soft; 
@@ -52,10 +54,10 @@ namespace FSpot.Editors {
 			box.PackStart (scale);
 			HBox actions = new HBox ();
 			actions.Spacing = 12;
-			Button cancel = new Button ("Cancel");
+			Button cancel = new Button (Catalog.GetString ("Cancel"));
 			cancel.Clicked += HandleCancel;
 			actions.PackStart (cancel);
-			Button apply = new Button ("Apply");
+			Button apply = new Button ( Catalog.GetString ("Apply"));
 			apply.Clicked += HandleApply;
 			actions.PackStart (apply);
 			box.PackStart (actions);
@@ -73,43 +75,45 @@ namespace FSpot.Editors {
 			BrowsablePointer item = view.Item;
 			EditTarget target = new EditTarget (item);
 			try { 
-				ImageFile img = ImageFile.Create (item.Current.DefaultVersionUri);
+				using (ImageFile img = ImageFile.Create (item.Current.DefaultVersionUri)) {
 
-				Cairo.Format format = view.CompletePixbuf ().HasAlpha ? Cairo.Format.Argb32 : Cairo.Format.Rgb24;
+					Cairo.Format format = view.CompletePixbuf ().HasAlpha ? Cairo.Format.Argb32 : Cairo.Format.Rgb24;
 
-				MemorySurface dest = new MemorySurface (format,
-									info.Bounds.Width,
-									info.Bounds.Height);
+					MemorySurface dest = new MemorySurface (format,
+										info.Bounds.Width,
+										info.Bounds.Height);
 
-				Context ctx = new Context (dest);
-				effect.OnExpose (ctx, info.Bounds);
-				((IDisposable)ctx).Dispose ();
+					Context ctx = new Context (dest);
+					effect.OnExpose (ctx, info.Bounds);
+					((IDisposable)ctx).Dispose ();
 
-				string tmp = ImageFile.TempPath (item.Current.DefaultVersionUri.LocalPath);
-				using (Gdk.Pixbuf output = Widgets.CairoUtils.CreatePixbuf (dest)) {
-					using (System.IO.Stream stream = System.IO.File.OpenWrite (tmp)) {
-						img.Save (output, stream);
+					string tmp = ImageFile.TempPath (item.Current.DefaultVersionUri.LocalPath);
+					using (Gdk.Pixbuf output = Widgets.CairoUtils.CreatePixbuf (dest)) {
+						using (System.IO.Stream stream = System.IO.File.OpenWrite (tmp)) {
+							img.Save (output, stream);
 						
+						}
 					}
+
+					dest.Destroy ();
+
+					// FIXME Not this again. I need to imlplement a real version of the transfer
+					// function that shows progress in the main window and allows for all the
+					// goodies we'll need.
+					//Gnome.Vfs.Result result = Gnome.Vfs.Result.Ok;
+					//result = Gnome.Vfs.Xfer.XferUri (new Gnome.Vfs.Uri (UriList.PathToFileUri (tmp).ToString ()),
+					Gnome.Vfs.Xfer.XferUri (new Gnome.Vfs.Uri (UriUtils.PathToFileUri (tmp).ToString ()),
+						new Gnome.Vfs.Uri (target.Uri.ToString ()),
+						Gnome.Vfs.XferOptions.Default,
+						Gnome.Vfs.XferErrorMode.Abort, 
+						Gnome.Vfs.XferOverwriteMode.Replace, 
+						delegate {
+							System.Console.Write (".");
+							return 1;
+						});
+
+					target.Commit ();
 				}
-
-				dest.Destroy ();
-
-				// FIXME Not this again. I need to imlplement a real version of the transfer
-				// function that shows progress in the main window and allows for all the
-				// goodies we'll need.
-				Gnome.Vfs.Result result = Gnome.Vfs.Result.Ok;
-				result = Gnome.Vfs.Xfer.XferUri (new Gnome.Vfs.Uri (UriList.PathToFileUri (tmp).ToString ()),
-								 new Gnome.Vfs.Uri (target.Uri.ToString ()),
-								 Gnome.Vfs.XferOptions.Default,
-								 Gnome.Vfs.XferErrorMode.Abort, 
-								 Gnome.Vfs.XferOverwriteMode.Replace, 
-								 delegate {
-									 System.Console.Write (".");
-									 return 1;
-								 });
-
-				target.Commit ();
 			} catch (System.Exception e) {
 				System.Console.WriteLine (e);
 				target.Delete ();
