@@ -21,6 +21,11 @@ using System.IO;
 using System;
 using Mono.Unix;
 
+using FSpot.Widgets;
+using FSpot;
+using FSpot.Utils;
+using FSpot.UI.Dialog;
+
 public class ImportCommand : FSpot.GladeDialog
 {
 	internal class SourceItem : ImageMenuItem
@@ -340,7 +345,7 @@ public class ImportCommand : FSpot.GladeDialog
 	
 	FSpot.PhotoImageView photo_view;
 	ImportBackend importer;
-	IconView tray;
+	FSpot.Widgets.IconView tray;
 
 	FSpot.Delay idle_start; 
 
@@ -602,7 +607,7 @@ public class ImportCommand : FSpot.GladeDialog
 		source_option_menu.Menu = menu;
 
 		collection = new FSpot.PhotoList (new Photo [0]);
-		tray = new FSpot.ScalingIconView (collection);
+		tray = new ScalingIconView (collection);
 		tray.Selection.Changed += HandleTraySelectionChanged;
 		icon_scrolled.SetSizeRequest (400, 200);
 		icon_scrolled.Add (tray);
@@ -615,9 +620,9 @@ public class ImportCommand : FSpot.GladeDialog
 		photo_scrolled.SetSizeRequest (200, 200);
 		photo_view.Show ();
 
-		//FSpot.Global.ModifyColors (frame_eventbox);
-		FSpot.Global.ModifyColors (photo_scrolled);
-		FSpot.Global.ModifyColors (photo_view);
+		//GtkUtil.ModifyColors (frame_eventbox);
+		GtkUtil.ModifyColors (photo_scrolled);
+		GtkUtil.ModifyColors (photo_view);
 
 		photo_view.Pixbuf = FSpot.Global.IconTheme.LoadIcon ("f-spot", 48, (Gtk.IconLookupFlags)0);
 		photo_view.Fit = true;
