@@ -15,6 +15,8 @@ using System.Text;
 using System.Collections;
 
 using Mono.Unix;
+using FSpot;
+using FSpot.Utils;
 
 public class TagCommands {
 
@@ -27,7 +29,7 @@ public class TagCommands {
 		TagStore tag_store;
 
 
-		[Glade.Widget] private Button ok_button;
+		[Glade.Widget] private Button create_button;
 		[Glade.Widget] private Entry tag_name_entry;
 		[Glade.Widget] private Label prompt_label;
 		[Glade.Widget] private Label already_in_use_label;
@@ -82,13 +84,13 @@ public class TagCommands {
 		private void Update ()
 		{
 			if (tag_name_entry.Text == String.Empty) {
-				ok_button.Sensitive = false;
+				create_button.Sensitive = false;
 				already_in_use_label.Markup = String.Empty;
 			} else if (TagNameExistsInCategory (tag_name_entry.Text, tag_store.RootCategory)) {
-				ok_button.Sensitive = false;
+				create_button.Sensitive = false;
 				already_in_use_label.Markup = "<small>" + Catalog.GetString ("This name is already in use") + "</small>";
 			} else {
-				ok_button.Sensitive = true;
+				create_button.Sensitive = true;
 				already_in_use_label.Markup = String.Empty;
 			}
 		}
@@ -251,23 +253,12 @@ public class TagCommands {
 			Menu menu = new Menu ();
 
 			foreach (Category category in categories) {
-				StringBuilder label_builder = new StringBuilder ();
-				
 				if (t.Category == category)
 					history = i;
 				
 				i++;
 				
-				for (Category parent = category.Category; 
-				     parent != null; 
-				     parent = parent.Category)
-					label_builder.Append ("  ");
-				
-				label_builder.Append (category.Name.Replace ("_", "__"));
-				
-				// FIXME escape underscores.
-				MenuItem item = new MenuItem (label_builder.ToString ());
-				menu.Append (item);
+				menu.Append (TagMenu.TagMenuItem.IndentedItem (category));
 			}
 			
 			category_option_menu.Sensitive = true;
@@ -455,9 +446,9 @@ public class TagCommands {
 			query = new FSpot.PhotoQuery (db.Photos);
 			
 			if (db.Tags.Hidden != null)
-				query.Terms = FSpot.Query.OrTerm.FromTags (new Tag []{ t, db.Tags.Hidden });
+				query.Terms = FSpot.OrTerm.FromTags (new Tag []{ t, db.Tags.Hidden });
 			else 
-				query.Terms = new FSpot.Query.Literal (t);
+				query.Terms = new FSpot.Literal (t);
 
 			image_view = new FSpot.PhotoImageView (query);
 			image_view.SelectionXyRatio = 1.0;
