@@ -1,5 +1,6 @@
 using System;
 using System.Collections;
+using FSpot.Query;
 
 namespace FSpot {
 	public class TimeAdaptor : GroupAdaptor, FSpot.ILimitable {
@@ -65,9 +66,9 @@ namespace FSpot {
 		{
 			Console.WriteLine ("{0} {1}", start, end);
 			if (start > end)
-				query.Range = new PhotoStore.DateRange (end, start);
+				query.Range = new DateRange (end, start);
 			else 
-				query.Range = new PhotoStore.DateRange (start, end);
+				query.Range = new DateRange (start, end);
 		}
 
 		public override int Count ()
@@ -195,7 +196,7 @@ namespace FSpot {
 		{
 			years.Clear ();
 
-			Photo [] photos = query.Store.Query ((Tag [])null, null, null, null);
+			Photo [] photos = query.Store.Query ((Tag [])null, null, null, null, null);
 			Array.Sort (query.Photos);
 			Array.Sort (photos);
 
